==> mew_4.2.orig.tar.gz: mew-4.2/auxiliary.el <==
(require 'mew-lang-jp)
(require 'mew-lang-latin)

(defvar FLD-MSG-LIST nil)
(defvar TOTAL nil)
(defvar WIDTH nil)
(defvar ange-ftp-generate-anonymous-password nil)
(defvar ange-ftp-tmp-name-template nil)
(defvar auto-image-file-mode nil)
(defvar coding-category-list nil)
(defvar default-file-name-coding-system nil)
(defvar elp-function-list nil)
(defvar elp-results-buffer nil)
(defvar find-file-hook nil)
(defvar inhibit-point-motion-hooks nil)
(defvar jka-compr-inhibit nil)
(defvar mark-active nil)
(defvar max-mini-window-height nil)
(defvar mode-line-position nil)
(defvar mule-version nil)
(defvar profile-buffer nil)
(defvar profile-functions-list nil)
(defvar system-time-locale nil)
(defvar transient-mark-mode nil)
(defvar w32-get-true-file-link-count nil)
(defvar w32-start-process-show-window nil)
(defvar w3m-content-type-alist nil)
(defvar w3m-namazu-index-alist nil)
(defvar x-dnd-protocol-alist nil)
(defvar x-dnd-test-function nil)

(defun amultibyte-string-p (&rest args))
(defun ange-ftp-copy-file-internal (&rest args))
(defun ange-ftp-expand-file-name (&rest args))
(defun ange-ftp-file-name-all-completions (&rest args))
(defun ange-ftp-file-name-completion (&rest args))
(defun bitmap-insert-xbm-file (&rest args))
(defun create-image (&rest args))
(defun display-graphic-p (&rest args))
(defun find-image (&rest args))
(defun image-size (&rest args))
(defun image-type-available-p (&rest args))
(defun image-type-available-p (&rest args))
(defun insert-image (&rest args))
(defun jit-lock-register (&rest args))
(defun multibyte-string-p (&rest args))
(defun mw32script-init (&rest args))
(defun mw32script-make-pathext-regexp (&rest args))
(defun mw32script-openp (&rest args))
(defun mw32script-resolve-script (&rest args))
(defun profile-functions (&rest args))
(defun propertize (&rest args))
(defun remove-images (&rest args))
(defun set-buffer-multibyte (&rest args))
(defun set-coding-priority (&rest args))
(defun string-as-multibyte (&rest args))
(defun string-as-unibyte (&rest args))
(defun tool-bar-add-item-from-menu (&rest args))
(defun tool-bar-local-item-from-menu (&rest args))
(defun update-coding-systems-internal (&rest args))
(defun w32-focus-frame (&rest args))
(defun w3m-expand-file-name-as-url (&rest args))
(defun w3m-namazu (&rest args))
(defun w3m-region (&rest args))
(defun w3m-url-local-p (&rest args))
(defun w3m-url-to-file-name (&rest args))
(defun x-dnd-choose-type (&rest args))
(defun x-dnd-get-local-file-name (&rest args))
(defun x-dnd-get-local-file-uri (&rest args))

==> mew-4.2.53.tar.gz: mew-4.2.53/auxiliary.el <==
(require 'mew-lang-jp)
(require 'mew-lang-latin)

(defvar FLD-MSG-LIST nil)
(defvar TOTAL nil)
(defvar WIDTH nil)
(defvar ange-ftp-generate-anonymous-password nil)
(defvar ange-ftp-tmp-name-template nil)
(defvar auto-image-file-mode nil)
(defvar coding-category-list nil)
(defvar default-file-name-coding-system nil)
(defvar elp-function-list nil)
(defvar elp-results-buffer nil)
(defvar find-file-hook nil)
(defvar inhibit-eol-conversion nil)
(defvar inhibit-point-motion-hooks nil)
(defvar jka-compr-inhibit nil)
(defvar mark-active nil)
(defvar max-mini-window-height nil)
(defvar mode-line-position nil)
(defvar mule-version nil)
(defvar profile-buffer nil)
(defvar profile-functions-list nil)
(defvar system-time-locale nil)
(defvar transient-mark-mode nil)
(defvar w32-get-true-file-link-count nil)
(defvar w32-start-process-show-window nil)
(defvar w3m-content-type-alist nil)
(defvar w3m-namazu-index-alist nil)
(defvar dnd-protocol-alist nil)
(defvar x-dnd-test-function nil)

(defun amultibyte-string-p (&rest args))
(defun ange-ftp-copy-file-internal (&rest args))
(defun ange-ftp-expand-file-name (&rest args))
(defun ange-ftp-file-name-all-completions (&rest args))
(defun ange-ftp-file-name-completion (&rest args))
(defun bitmap-insert-xbm-file (&rest args))
(defun create-image (&rest args))
(defun define-process-argument-editing (&rest args))
(defun display-graphic-p (&rest args))
(defun find-image (&rest args))
(defun general-process-argument-editing-function (&rest args))
(defun image-size (&rest args))
(defun image-type-available-p (&rest args))
(defun image-type-available-p (&rest args))
(defun insert-image (&rest args))
(defun jit-lock-register (&rest args))
(defun multibyte-string-p (&rest args))
(defun mw32script-init (&rest args))
(defun mw32script-make-pathext-regexp (&rest args))
(defun mw32script-openp (&rest args))
(defun mw32script-resolve-script (&rest args))
(defun profile-functions (&rest args))
(defun propertize (&rest args))
(defun remove-images (&rest args))
(defun set-buffer-multibyte (&rest args))
(defun set-coding-priority (&rest args))
(defun string-as-multibyte (&rest args))
(defun string-as-unibyte (&rest args))
(defun tool-bar-add-item-from-menu (&rest args))
(defun tool-bar-local-item-from-menu (&rest args))
(defun update-coding-systems-internal (&rest args))
(defun w32-focus-frame (&rest args))
(defun w3m-expand-file-name-as-url (&rest args))
(defun w3m-namazu (&rest args))
(defun w3m-region (&rest args))
(defun w3m-url-local-p (&rest args))
(defun w3m-url-to-file-name (&rest args))
(defun x-dnd-choose-type (&rest args))
(defun dnd-get-local-file-name (&rest args))
(defun dnd-get-local-file-uri (&rest args))
